<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2021 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize;

use _JchOptimizeVendor\Joomla\Input\Input;
use Psr\Container\ContainerExceptionInterface;
use Psr\Container\ContainerInterface;
use Psr\Container\NotFoundExceptionInterface;

class ControllerResolver
{
    /**
     * @var ContainerInterface
     */
    private $container;

    /**
     * @var Input
     */
    private $input;

    public function __construct(ContainerInterface $container, Input $input)
    {
        $this->container = $container;
        $this->input = $input;
    }

    /**
     * @throws ContainerExceptionInterface
     * @throws NotFoundExceptionInterface
     */
    public function resolve()
    {
        $controller = $this->getController();
        if ($this->container->has($controller)) {
            \call_user_func([$this->container->get($controller), 'execute']);
        } else {
            throw new \InvalidArgumentException(\sprintf('Cannot resolve controller aliased: %s', $controller));
        }
    }

    private function getController()
    {
        $task = $this->input->get('task', null);
        if (!\is_null($task)) {
            return $task;
        }
        $view = $this->input->get('view', null);
        $tab = $this->input->get('tab', null);
        if (!\is_null($tab) && \is_null($view)) {
            return $tab;
        }
        if (!\is_null($view)) {
            return $view;
        }

        return 'main';
    }
}
