<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2022 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 *  If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Core\Css\Callbacks;

\defined('_JCH_EXEC') or exit('Restricted access');
class CombineMediaQueries extends \JchOptimize\Core\Css\Callbacks\AbstractCallback
{
    private $cssInfos = [];

    public function processMatches($matches, $context)
    {
        if (empty($this->cssInfos['media'])) {
            return $matches[0];
        }
        if ('media' == $context) {
            return '@media '.$this->combineMediaQueries($this->cssInfos['media'], \trim(\substr($matches[2], 6))).'{'.$matches[4].'}';
        }
        if ('import' == $context) {
            $sMediaQuery = $matches[7];
            $sAtImport = \substr($matches[0], 0, -\strlen($sMediaQuery.';'));

            return $sAtImport.' '.$this->combineMediaQueries($this->cssInfos['media'], $sMediaQuery).';';
        }

        return '@media '.$this->cssInfos['media'].'{'.$matches[0].'}';
    }

    public function setCssInfos($cssInfos)
    {
        $this->cssInfos = $cssInfos;
    }

    /**
     * @param string $sParentMediaQueries
     * @param string $sChildMediaQueries
     *
     * @return string
     */
    protected function combineMediaQueries($sParentMediaQueries, $sChildMediaQueries)
    {
        $aParentMediaQueries = \preg_split('#\\s++or\\s++|,#i', $sParentMediaQueries);
        $aChildMediaQueries = \preg_split('#\\s++or\\s++|,#i', $sChildMediaQueries);
        // $aMediaTypes = array('all', 'aural', 'braille', 'handheld', 'print', 'projection', 'screen', 'tty', 'tv', 'embossed');
        $aMediaQuery = [];
        foreach ($aParentMediaQueries as $sParentMediaQuery) {
            $aParentMediaQuery = $this->parseMediaQuery(\trim($sParentMediaQuery));
            foreach ($aChildMediaQueries as $sChildMediaQuery) {
                $sMediaQuery = '';
                $aChildMediaQuery = $this->parseMediaQuery(\trim($sChildMediaQuery));
                if ('only' == $aParentMediaQuery['keyword'] || 'only' == $aChildMediaQuery['keyword']) {
                    $sMediaQuery .= 'only ';
                }
                if ('not' == $aParentMediaQuery['keyword'] && '' == $sChildMediaQuery['keyword']) {
                    if ('all' == $aParentMediaQuery['media_type']) {
                        $sMediaQuery .= '(not '.$aParentMediaQuery['media_type'].')';
                    } elseif ($aParentMediaQuery['media_type'] == $aChildMediaQuery['media_type']) {
                        $sMediaQuery .= '(not '.$aParentMediaQuery['media_type'].') and '.$aChildMediaQuery['media_type'];
                    } else {
                        $sMediaQuery .= $aChildMediaQuery['media_type'];
                    }
                } elseif ('' == $aParentMediaQuery['keyword'] && 'not' == $aChildMediaQuery['keyword']) {
                    if ('all' == $aChildMediaQuery['media_type']) {
                        $sMediaQuery .= '(not '.$aChildMediaQuery['media_type'].')';
                    } elseif ($aParentMediaQuery['media_type'] == $aChildMediaQuery['media_type']) {
                        $sMediaQuery .= $aParentMediaQuery['media_type'].' and (not '.$aChildMediaQuery['media_type'].')';
                    } else {
                        $sMediaQuery .= $aChildMediaQuery['media_type'];
                    }
                } elseif ('not' == $aParentMediaQuery['keyword'] && 'not' == $aChildMediaQuery['keyword']) {
                    $sMediaQuery .= 'not '.$aChildMediaQuery['keyword'];
                } else {
                    if ($aParentMediaQuery['media_type'] == $aChildMediaQuery['media_type'] || 'all' == $aParentMediaQuery['media_type']) {
                        $sMediaQuery .= $aChildMediaQuery['media_type'];
                    } elseif ('all' == $aChildMediaQuery['media_type']) {
                        $sMediaQuery .= $aParentMediaQuery['media_type'];
                    } else {
                        // Two different media types are nested and neither is 'all' then
                        // the enclosed rule will not be applied on any media type
                        // We put 'not all' to maintain a syntactically correct combined media type
                        $sMediaQuery .= 'not all';
                        // Don't bother including media features in the media query
                        $aMediaQuery[] = $sMediaQuery;

                        continue;
                    }
                }
                if (isset($aParentMediaQuery['expression'])) {
                    $sMediaQuery .= ' and '.$aParentMediaQuery['expression'];
                }
                if (isset($aChildMediaQuery['expression'])) {
                    $sMediaQuery .= ' and '.$aChildMediaQuery['expression'];
                }
                $aMediaQuery[] = $sMediaQuery;
            }
        }

        return \implode(', ', \array_unique($aMediaQuery));
    }

    protected function parseMediaQuery($sMediaQuery)
    {
        $aParts = [];
        $sMediaQuery = \preg_replace(['#\\(\\s++#', '#\\s++\\)#'], ['(', ')'], $sMediaQuery);
        \preg_match('#(?:\\(?(not|only)\\)?)?\\s*+(?:\\(?(all|screen|print|speech|aural|tv|tty|projection|handheld|braille|embossed)\\)?)?(?:\\s++and\\s++)?(.++)?#si', $sMediaQuery, $aMatches);
        $aParts['keyword'] = isset($aMatches[1]) ? \strtolower($aMatches[1]) : '';
        if (isset($aMatches[2]) && '' != $aMatches[2]) {
            $aParts['media_type'] = \strtolower($aMatches[2]);
        } else {
            $aParts['media_type'] = 'all';
        }
        if (isset($aMatches[3]) && '' != $aMatches[3]) {
            $aParts['expression'] = $aMatches[3];
        }

        return $aParts;
    }
}
