<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Html\Renderer;

use JchOptimize\Html\CacheStorageSupportHelper;
use JchOptimize\Html\Helper;

abstract class Setting
{
    public static function pro_downloadid()
    {
        echo Helper::_('text.pro', __FUNCTION__, '');
    }

    public static function debug()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function order_plugin()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function disable_logged_in_users()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function menuexcludedurl()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'url', 'file');
    }

    public static function combine_files_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function pro_smart_combine()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0', 'jch-smart-combine-radios-wrapper');
    }

    public static function cache_lifetime()
    {
        $aOptions = ['1800' => \__('30 min', 'jch-optimize'), '3600' => \__('1 hour', 'jch-optimize'), '10800' => \__('3 hours', 'jch-optimize'), '21600' => \__('6 hours', 'jch-optimize'), '43200' => \__('12 hours', 'jch-optimize'), '86400' => \__('1 day', 'jch-optimize'), '172800' => \__('2 days', 'jch-optimize'), '604800' => \__('7 days', 'jch-optimize'), '1209600' => \__('2 weeks', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, '1800', $aOptions);
    }

    public static function delete_expiry()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function html_minify_level()
    {
        $aOptions = ['0' => \__('Basic', 'jch-optimize'), '1' => \__('Advanced', 'jch-optimize'), '2' => \__('Ultra', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, '0', $aOptions);
    }

    public static function htaccess()
    {
        $aOptions = ['2' => \__('Static css and js files', 'jch-optimize'), '0' => \__('PHP file with query', 'jch-optimize'), '1' => \__('PHP using url re-write', 'jch-optimize'), '3' => \__('PHP using url re-write (Without Options +FollowSymLinks)', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, '2', $aOptions);
    }

    public static function try_catch()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function gzip()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function html_minify()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function includeAllExtensions()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function phpAndExternal()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function css()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function css_minify()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function replaceImports()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function inlineStyle()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function excludeCss()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'css', 'file');
    }

    public static function excludeCssComponents()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'css', 'extension');
    }

    public static function excludeStyles()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'css', 'style');
    }

    public static function excludeAllStyles()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function remove_css()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'css', 'file');
    }

    public static function optimizeCssDelivery_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function optimizeCssDelivery()
    {
        $aOptions = ['600' => '600', '800' => '800', '1000' => '1000'];
        echo Helper::_('select', __FUNCTION__, '800', $aOptions);
    }

    public static function pro_reduce_unused_css()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_dynamic_selectors()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'selectors', 'style');
    }

    public static function javascript()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function js_minify()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function inlineScripts()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function bottom_js()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function loadAsynchronous()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function pro_reduce_unused_js_enable()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_criticalJs()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'js', 'file');
    }

    public static function pro_criticalScripts()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'js', 'script');
    }

    public static function pro_criticalModules()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'js', 'file');
    }

    public static function pro_criticalModulesScripts()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'js', 'script');
    }

    public static function excludeJs_peo()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'file');
    }

    public static function excludeJsComponents_peo()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'extension');
    }

    public static function excludeScripts_peo()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'script');
    }

    public static function excludeAllScripts()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function excludeJs()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'file');
    }

    public static function excludeJsComponents()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'extension');
    }

    public static function excludeScripts()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'script');
    }

    public static function dontmoveJs()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'file');
    }

    public static function dontmoveScripts()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'script');
    }

    public static function remove_js()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'js', 'file');
    }

    public static function cache_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function pro_cache_platform()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function page_cache_exclude_form_users()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function page_cache_lifetime()
    {
        $aOptions = ['900' => \__('15 min', 'jch-optimize'), '1800' => \__('30 min', 'jch-optimize'), '3600' => \__('1 hour', 'jch-optimize'), '10800' => \__('3 hours', 'jch-optimize'), '21600' => \__('6 hours', 'jch-optimize'), '43200' => \__('12 hours', 'jch-optimize'), '86400' => \__('1 day', 'jch-optimize'), '172800' => \__('2 days', 'jch-optimize'), '604800' => \__('1 week', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, '900', $aOptions);
    }

    public static function cache_exclude()
    {
        // We're using class as the last argument to be able to include '?' in the multiselect box
        echo Helper::_('multiselect', __FUNCTION__, [], 'url', 'class');
    }

    public static function pro_capture_cache_enable()
    {
        $default = \is_multisite() ? '0' : '1';
        echo Helper::_('radio.pro', __FUNCTION__, $default);
    }

    public static function pro_cache_storage_adapter()
    {
        $options = ['filesystem' => \__('Filesystem', 'jch-optimize'), 'apcu' => \__('APCu', 'jch-optimize'), 'wincache' => \__('WinCache', 'jch-optimize'), 'memcached' => \__('Memcached', 'jch-optimize'), 'redis' => \__('Redis', 'jch-optimize')];
        $class = CacheStorageSupportHelper::class;
        $conditions = ['apcu' => [$class, 'isApcuSupported'], 'wincache' => [$class, 'isWincacheSupported'], 'memcached' => [$class, 'isMemcachedSupported'], 'redis' => [$class, 'isRedisSupported']];
        echo Helper::_('select.pro', __FUNCTION__, 'filesystem', $options, '', $conditions);
    }

    public static function memcached_server_host()
    {
        echo Helper::_('text.pro', __FUNCTION__, '127.0.0.1');
    }

    public static function memcached_server_port()
    {
        echo Helper::_('text.pro', __FUNCTION__, '11211');
    }

    public static function redis_server_host()
    {
        echo Helper::_('text.pro', __FUNCTION__, '127.0.0.1');
    }

    public static function redis_server_port()
    {
        echo Helper::_('text.pro', __FUNCTION__, '6379');
    }

    public static function redis_server_password()
    {
        echo Helper::_('text.pro', __FUNCTION__, '');
    }

    public static function redis_server_database()
    {
        echo Helper::_('text.pro', __FUNCTION__, '0');
    }

    public static function img_attributes_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function csg_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function csg_direction()
    {
        $aOptions = ['vertical' => \__('vertical', 'jch-optimize'), 'horizontal' => \__('horizontal', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, 'vertical', $aOptions);
    }

    public static function csg_wrap_images()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function csg_exclude_images()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'images', 'file');
    }

    public static function csg_include_images()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'images', 'file');
    }

    public static function lazyload_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function lazyload_autosize()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function pro_lazyload_effects()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_lazyload_iframe()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_lazyload_audiovideo()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_lazyload_bgimages()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_lazyload_css_bgimages()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'css', 'class');
    }

    public static function excludeLazyLoad()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'lazyload', 'file');
    }

    public static function pro_excludeLazyLoadFolders()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'lazyload', 'folder');
    }

    public static function pro_excludeLazyLoadClass()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'lazyload', 'class');
    }

    public static function http2_push_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function pro_http2_exclude_deferred()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_http2_preload_modules()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '1');
    }

    public static function pro_http2_push_cdn()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_http2_file_types()
    {
        $aOptions = ['style' => 'style', 'script' => 'script', 'font' => 'font', 'image' => 'image'];
        echo Helper::_('checkboxes', __FUNCTION__, \array_keys($aOptions), $aOptions);
    }

    public static function pro_http2_include()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'http2', 'file');
    }

    public static function pro_http2_exclude()
    {
        echo Helper::_('multiselect', __FUNCTION__, [], 'http2', 'file');
    }

    public static function pro_optimizeFonts_enable()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_force_swap_policy()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '1');
    }

    public static function pro_optimize_font_files()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'css', 'file');
    }

    public static function pro_preconnect_domains()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'url', 'file');
    }

    public static function cookielessdomain_enable()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function pro_cdn_preconnect()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function cdn_scheme()
    {
        $aOptions = ['0' => \__('scheme relative', 'jch-optimize'), '1' => \__('http', 'jch-optimize'), '2' => \__('https', 'jch-optimize')];
        echo Helper::_('select', __FUNCTION__, 0, $aOptions);
    }

    public static function cookielessdomain()
    {
        echo Helper::_('text', __FUNCTION__, '');
    }

    public static function staticfiles()
    {
        echo Helper::_('checkboxes', __FUNCTION__, \array_keys(self::staticFilesArray()), self::staticFilesArray());
    }

    public static function pro_customcdnextensions()
    {
        echo Helper::_('multiselect.pro', __FUNCTION__, [], 'url', 'file');
    }

    public static function pro_cookielessdomain_2()
    {
        echo Helper::_('text.pro', __FUNCTION__, '');
    }

    public static function pro_staticfiles_2()
    {
        echo Helper::_('checkboxes.pro', __FUNCTION__, \array_keys(self::staticFilesArray()), self::staticFilesArray());
    }

    public static function pro_cookielessdomain_3()
    {
        echo Helper::_('text.pro', __FUNCTION__, '');
    }

    public static function pro_staticfiles_3()
    {
        echo Helper::_('checkboxes.pro', __FUNCTION__, \array_keys(self::staticFilesArray()), self::staticFilesArray());
    }

    public static function ignore_optimized()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function pro_next_gen_images()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '1');
    }

    public static function pro_web_old_browsers()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function lossy()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function save_metadata()
    {
        echo Helper::_('radio', __FUNCTION__, '0');
    }

    public static function pro_api_resize_mode()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '1');
    }

    public static function recursive()
    {
        echo Helper::_('radio', __FUNCTION__, '1');
    }

    public static function pro_reduce_dom()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    public static function pro_html_sections()
    {
        $options = ['section' => 'section', 'header' => 'header', 'footer' => 'footer', 'aside' => 'aside', 'nav' => 'nav'];
        echo Helper::_('checkboxes.pro', __FUNCTION__, \array_keys($options), $options);
    }

    public static function pro_disableModeSwitcher()
    {
        echo Helper::_('radio.pro', __FUNCTION__, '0');
    }

    private static function staticFilesArray()
    {
        return ['css' => 'css', 'png' => 'png', 'gif' => 'gif', 'ico' => 'ico', 'pdf' => 'pdf', 'js' => 'js', 'jpe?g' => 'jp(e)g', 'bmp' => 'bmp', 'webp' => 'webp', 'svg' => 'svg'];
    }
}
