<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Platform;

use JchOptimize\Core\Interfaces\Excludes as ExcludesInterface;

\defined('_WP_EXEC') or exit('Restricted access');
class Excludes implements ExcludesInterface
{
    /**
     * @param string $type
     * @param string $section
     *
     * @return array|void
     */
    public static function body($type, $section = 'file')
    {
        if ('js' == $type) {
            if ('script' == $section) {
                return [];
            }

            return ['js.stripe.com'];
        }
        if ('css' == $type) {
            return [];
        }
    }

    public static function extensions(): string
    {
        return \JchOptimize\Platform\Paths::rewriteBaseFolder();
    }

    /**
     * @param string $type
     * @param string $section
     *
     * @return array|void
     */
    public static function head($type, $section = 'file')
    {
        if ('js' == $type) {
            if ('script' == $section) {
                return [];
            }

            return ['js.stripe.com'];
        }
        if ('css' == $type) {
            return [];
        }
    }

    /**
     * @param string $url
     *
     * @return bool
     */
    public static function editors($url)
    {
        return \preg_match('#/editors/#i', $url);
    }

    public static function smartCombine()
    {
        return ['wp-includes/', 'wp-content/themes/', '.'];
    }
}
