<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2020 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Plugin;

use _JchOptimizeVendor\Joomla\Filesystem\File;
use _JchOptimizeVendor\Joomla\Filesystem\Folder;
use JchOptimize\Container;
use JchOptimize\Core\Admin\Tasks;
use JchOptimize\Model\Cache;

class Installer
{
    /**
     * Fires when plugin is activated and create a dir.php file in plugin root containing
     * absolute path of plugin install.
     */
    public function activate(): void
    {
        $file = \JCH_PLUGIN_DIR.'dir.php';
        $absPath = \ABSPATH;
        $code = <<<PHPCODE
<?php
           
\$DIR = '{$absPath}';
           
PHPCODE;
        File::write($file, $code);
        Tasks::leverageBrowserCaching();
        if (\JCH_PRO) {
            // Copy the mu-plugins in the correct folder
            $mu_folder = \ABSPATH.'wp-content/mu-plugins';
            if (\defined('WPMU_PLUGIN_DIR') && \WPMU_PLUGIN_DIR) {
                $mu_folder = \WPMU_PLUGIN_DIR;
            }
            if (!\is_dir($mu_folder)) {
                Folder::create($mu_folder);
            }
            File::copy(\JCH_PLUGIN_DIR.'mu-plugins/jch-optimize-mode-switcher.php', $mu_folder.'/jch-optimize-mode-switcher.php');
        }
    }

    public function deactivate(): void
    {
        \delete_option('jch-optimize_settings');

        /** @var Cache $cache */
        $container = Container::getInstance();
        $cache = $container->get(Cache::class);
        $cache->cleanCache();
        Tasks::cleanHtaccess();
        if (\JCH_PRO) {
            $mu_folder = \ABSPATH.'wp-content/mu-plugins';
            if (\defined('WPMU_PLUGIN_DIR') && \WPMU_PLUGIN_DIR) {
                $mu_folder = \WPMU_PLUGIN_DIR;
            }
            File::delete($mu_folder.'/jch-optimize-mode-switcher.php');
        }
    }
}
